
/**
 * PyOtherSide: Asynchronous Python 3 Bindings for Qt 5
 * Copyright (c) 2014, Thomas Perl <m@thp.io>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
 * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 **/

#ifndef PYOTHERSIDE_PYQOBJECT_H
#define PYOTHERSIDE_PYQOBJECT_H

#include "python_wrap.h"

#include "qobject_ref.h"

typedef struct {
    PyObject_HEAD
    QObjectRef *m_qobject_ref;
} pyotherside_QObject;

typedef struct {
    PyObject_HEAD
    QObjectMethodRef *m_method_ref;
} pyotherside_QObjectMethod;

extern PyTypeObject pyotherside_QObjectType;
extern PyTypeObject pyotherside_QObjectMethodType;

#endif /* PYOTHERSIDE_PYQOBJECT_H */
